==> guikachu-0.7.tar.gz: guikachu-0.7/src/form-editor/list.h <==
//$Id: list.h,v 1.2 2001/05/06 21:59:37 cactus Exp $ -*- c++ -*-

/* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2
 * as published by the Free Software Foundation.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */

#ifndef GUIKACHU_FORM_EDITOR_LIST_H
#define GUIKACHU_FORM_EDITOR_LIST_H

#include <string>
#include <iostream>
#include <gnome-xml/tree.h>
#include <sigc++/basic_signal.h>

#include "widget.h"
#include "resource.h"

namespace Guikachu
{
    namespace Widgets
    {
	class List;
    }
}

#include "list-prop.h"

#include <vector>

namespace Guikachu
{
    namespace Widgets
    {
	class List: public Widget
	{
	    GUI::FormEditor::ListProperties *editor;
	    
	public:
	    List (Resources::Form *owner,
		  const string& id);
	    virtual ~List ();
	    
	    virtual Type get_type () const { return WIDGET_LIST; };
	    
	    virtual GUI::FormEditor::CanvasItem *get_canvas_item (GUI::FormEditor::Form *form);
	    virtual Gtk::Widget *get_editor ();
	    
	    GUIKACHU_RESOURCE_PROP (font,          int);
	    GUIKACHU_RESOURCE_PROP (visible_items, int);
	    GUIKACHU_RESOURCE_PROP (usable,        bool);

	    GUIKACHU_RESOURCE_PROP (items,         vector<string>);
	    
	    GUIKACHU_RESOURCE_PROP (width,         int);
	    GUIKACHU_RESOURCE_PROP (manual_width,  bool);
	    
	private:
	    // Persistance
	    virtual bool load (xmlDocPtr xml_doc, xmlNodePtr node);
	    virtual void save (xmlNodePtr node) const;
	    virtual void save_rcp (ostream &ostr) const;
	};
    }
}

#endif /* !GUIKACHU_FORM_EDITOR_LIST_H */

==> guikachu-0.9.tar.gz: guikachu-0.9/src/form-editor/list.h <==
//$Id: list.h,v 1.3 2001/08/18 14:23:02 cactus Exp $ -*- c++ -*-

/* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2
 * as published by the Free Software Foundation.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */

#ifndef GUIKACHU_FORM_EDITOR_LIST_H
#define GUIKACHU_FORM_EDITOR_LIST_H

#include <string>
#include <iostream>
#include <gnome-xml/tree.h>
#include <sigc++/basic_signal.h>

#include "widget.h"
#include "resource.h"

namespace Guikachu
{
    namespace Widgets
    {
	class List;
    }
}

#include "list-prop.h"

#include <vector>

namespace Guikachu
{
    namespace Widgets
    {
	class List: public Widget
	{
	    GUI::FormEditor::ListProperties *editor;
	    
	public:
	    List (Resources::Form *owner,
		  const string& id);
	    virtual ~List ();
	    
	    virtual Type get_type () const { return WIDGET_LIST; };
	    
	    virtual GUI::FormEditor::CanvasItem *get_canvas_item (GUI::FormEditor::Form *form);
	    virtual Gtk::Widget *get_editor ();

	    Property<int>             font;
	    Property<int>             visible_items;
	    Property<bool>            usable;
	    Property<vector<string> > items;
	    Property<int>             width;
	    Property<bool>            manual_width;
	    
	private:
	    // Persistance
	    virtual bool load (xmlDocPtr xml_doc, xmlNodePtr node);
	    virtual void save (xmlNodePtr node) const;
	    virtual void save_rcp (ostream &ostr) const;
	};
    }
}

#endif /* !GUIKACHU_FORM_EDITOR_LIST_H */
